@@ -1,4 +1,4 @@
-autorun.jags <- function(model=stop("No model supplied"), monitor = stop("No monitored variables supplied"), data=NA, n.chains=2, inits = replicate(n.chains, NA), startburnin = 5000, startsample = 10000, psrf.target = 1.05, normalise.mcmc = TRUE, check.stochastic = TRUE, raftery.options = list(), crash.retry=1, plots = TRUE, thin.sample = TRUE, jags = findjags(), silent.jags = FALSE, interactive=TRUE, max.time=Inf, adaptive=list(type="burnin", length=200), modules=c(""), factories=c(""), thin = 1, monitor.deviance = FALSE, monitor.pd = FALSE, monitor.pd.i = FALSE, monitor.popt = FALSE, keep.jags.files=FALSE, tempdir=TRUE, method=if(.Platform$OS.type=='unix' & .Platform$GUI!="AQUA" & Sys.info()['user']!='nobody') 'interruptible' else 'simple'){
+autorun.jags <- function(model=stop("No model supplied"), monitor = stop("No monitored variables supplied"), data=NA, n.chains=2, inits = replicate(n.chains, NA), startburnin = 5000, startsample = 10000, psrf.target = 1.05, normalise.mcmc = TRUE, check.stochastic = TRUE, raftery.options = list(), crash.retry=1, plots = TRUE, thin.sample = TRUE, jags = findjags(), silent.jags = FALSE, interactive=TRUE, max.time=Inf, adaptive=list(type="burnin", length=200), modules=c(""), factories=c(""), thin = 1, monitor.deviance = FALSE, monitor.pd = FALSE, monitor.pd.i = FALSE, monitor.popt = FALSE, keep.jags.files=FALSE, tempdir=TRUE, method=if(.Platform$OS.type=='unix' & .Platform$GUI!="AQUA" & Sys.info()['user']!='nobody') 'interruptible' else 'simple', batch.jags=silent.jags){
 	
 	if(any(tolower(monitor)=='dic')){
 		dic <- TRUE
@@ -102,7 +102,7 @@ autorun.jags <- function(model=stop("No model supplied"), monitor = stop("No mon
 	pre.time <- Sys.time()
 	
 	
-	pilot <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits = inits, burnin=startburnin, sample=startsample, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method)
+	pilot <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits = inits, burnin=startburnin, sample=startsample, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method, batch.jags=batch.jags)
 	if(any(pilot=="Unable to load coda files")){
 		swcat("An error occured during the simulation\n\n")
 		return(c("Error", "An error occured during the simulation"))
@@ -127,7 +127,7 @@ autorun.jags <- function(model=stop("No model supplied"), monitor = stop("No mon
 			swcat("\nThe simulation crashed; retrying...",newlines,sep="")			
 			crash.retry <- crash.retry - 1
 			oldpilot <- pilot
-			pilot <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits = inits, burnin=startburnin, sample=startsample, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method)
+			pilot <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits = inits, burnin=startburnin, sample=startsample, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method, batch.jags=batch.jags)
 			
 			if(!any(names(pilot)=="crash.end")) break
 		}
@@ -233,7 +233,7 @@ autorun.jags <- function(model=stop("No model supplied"), monitor = stop("No mon
 				if(neededupdates > 0){
 					
 					oldadditional <- additional
-					additional <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits=pilot$end.state, burnin=burnadapt, sample=neededupdates, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method)
+					additional <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits=pilot$end.state, burnin=burnadapt, sample=neededupdates, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method, batch.jags=batch.jags)
 					
 					if(any(pilot=="Unable to load coda files")){
 						swcat("\nThere was an error in the second simulation, possibly due to bad initial values or Random Number Seed values obtained from the first simulation.  You could try using fewer chains.")
@@ -254,7 +254,7 @@ autorun.jags <- function(model=stop("No model supplied"), monitor = stop("No mon
 							swcat("\nThe simulation crashed; retrying...",newlines,sep="")
 							crash.retry <- crash.retry - 1
 							oldadd <- additional
-							additional <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits = oldadditional$end.state, burnin=burnadapt, sample=(neededupdates), adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method)
+							additional <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits = oldadditional$end.state, burnin=burnadapt, sample=(neededupdates), adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method, batch.jags=batch.jags)
 							
 							if(!any(names(additional)=="crash.end")) break
 						}
@@ -512,7 +512,7 @@ autorun.jags <- function(model=stop("No model supplied"), monitor = stop("No mon
 		
 		
 		swcat("\n")
-		additional <- run.jags(data=data, model=model, monitor=monitor,  n.chains=n.chains, inits=pilot$end.state, burnin=burnadapt, sample=moreupdates, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method)
+		additional <- run.jags(data=data, model=model, monitor=monitor,  n.chains=n.chains, inits=pilot$end.state, burnin=burnadapt, sample=moreupdates, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method, batch.jags=batch.jags)
 		if(any(additional=="Unable to load coda files")){
 			swcat("An error occured during the simulation\n\n")
 			return(c("Error", "An error occured during the simulation"))
@@ -528,7 +528,7 @@ autorun.jags <- function(model=stop("No model supplied"), monitor = stop("No mon
 				swcat("\nThe simulation crashed; retrying...",newlines,sep="")			
 				crash.retry <- crash.retry - 1
 				oldadd <- additional
-				additional <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits = pilot$end.state, burnin=burnadapt, sample=moreupdates, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method)
+				additional <- run.jags(data=data, model=model, monitor=monitor, n.chains=n.chains, inits = pilot$end.state, burnin=burnadapt, sample=moreupdates, adapt=adapt, silent.jags=silent.jags, plots = FALSE, check.conv=FALSE, jags = jags, psrf.target = psrf.target, normalise.mcmc=normalise.mcmc, check.stochastic = check.stochastic, modules=modules, factories=factories, thin=thin, monitor.deviance=monitor.deviance, monitor.pd=monitor.pd, monitor.pd.i=monitor.pd.i, monitor.popt=monitor.popt, keep.jags.files=keep.jags.files, tempdir=tempdir, method=method, batch.jags=batch.jags)
 				if(any(additional=="Unable to load coda files")){
 					swcat("An error occured during the simulation\n\n")
 					return(c("Error", "An error occured during the simulation"))
